#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include <SDL.h>
#include <SDL_ttf.h>

TTF_Font *font;

/* Buttons */
enum {
	GP2X_START = 8,
};

void
draw_text(SDL_Surface *screen, SDL_Color c, int x, int y, char *str)
{
	SDL_Surface* s =  TTF_RenderText_Blended(font, str, c);
	SDL_Rect r = { x, y, 0, 0 };
	SDL_BlitSurface(s, NULL, screen, &r);
	SDL_FreeSurface(s);
}

void
quit(void)
{
	SDL_Quit();
	chdir("/usr/gp2x");
	execl("/usr/gp2x/gp2xmenu", "/usr/gp2x/gp2xmenu", NULL);
}

int
main(int argc, char *argv[])
{
	int down=0, up=0;
	char buf[1024];
	SDL_Surface *screen;
	SDL_Event event;
	SDL_Color black = { 0, 0, 0 };
	Uint32 white;
	
	if(SDL_Init(SDL_INIT_JOYSTICK | SDL_INIT_VIDEO) < 0){
		fprintf(stderr, "Couldn't initialize SDL\n");
		exit(1);
	}
	atexit(quit);
	screen = SDL_SetVideoMode(320, 240, 16, SDL_SWSURFACE);
	if(!screen){
		fprintf(stderr, "Couldn't set video mode\n");
		exit(1);
	}

	SDL_JoystickOpen(0);
	/* If we don't ignore motion events, the queue fills
	 * with them during drags and nothing gets done until
	 * the stylus rests for a while.  Better to poll the position
	 * when we want to know.
	 */
	SDL_EventState(SDL_MOUSEMOTION, SDL_IGNORE);
	
	TTF_Init();
	font = TTF_OpenFont("./vera.ttf", 12);

	white = SDL_MapRGB(screen->format, 0xFF, 0xFF, 0xFF);
	
	while(1){
		int x, y;
		while(SDL_PollEvent(&event)){
			switch(event.type){
			case SDL_QUIT:
				goto end;
			case SDL_JOYBUTTONDOWN:
				if(event.jbutton.button == GP2X_START)
					goto end;
				break;
			case SDL_MOUSEBUTTONDOWN:
				/* The click location is in event.button.x and event.button.y. */ 
				down++;
				break;
			case SDL_MOUSEBUTTONUP:
				up++;
				break;
			}
		}
		/* The GP2X reports screen touches as button 3,
		 * but we only care that some button's pressed.
		 */
		if(SDL_GetMouseState(&x, &y))
			snprintf(buf, sizeof(buf), "Screen pressed at (%d, %d)", x, y);
		else
			snprintf(buf, sizeof(buf), "Screen not pressed (events: %d down, %d up)", down, up);
		SDL_FillRect(screen, NULL, white);
		draw_text(screen, black, 0, 10, buf);

		if(SDL_Flip(screen)<0){
			fprintf(stderr,"SDL_Flip failed\n");
			exit(1);
		}
	}
end:
	SDL_FreeSurface(screen);
	TTF_CloseFont(font);
	return 0;
}
